# Nordstrom reporter
A simple commandline app for automate Nordstrom reports

# Usage
```bash
$ nordstrompy notes --outputfile <filepath to outputfile>

$ nordstrompy keywords --inputfile <filepath to source file> --outputfile <filepath to source file>
```